@@ -30,7 +30,9 @@ u32_tolower (const uint32_t *s, size_t n, const char *iso639_language,
 	     uninorm_t nf,
 	     uint32_t *resultbuf, size_t *lengthp)
 {
-  return u32_casemap (s, n, iso639_language,
+  return u32_casemap (s, n,
+		      unicase_empty_prefix_context, unicase_empty_suffix_context,
+		      iso639_language,
 		      uc_tolower, offsetof (struct special_casing_rule, lower[0]),
 		      nf,
 		      resultbuf, lengthp);
